//-----------------------------------------------------------------------------
// Title      : prj_ub003_mk3_bma180
//-----------------------------------------------------------------------------
// Funktion   : Beschleunigungs-Sensor-Modul (BMA180)
// Schaltung  : myAVR MK3 + BMA180-Modul
//-----------------------------------------------------------------------------
// Prozessor  : ATMega2560
// Takt       : 16 MHz
// Sprache    : C
// Date       : 18.12.2010
// Version    : 1.2
// Autor      : UB
//-----------------------------------------------------------------------------
#define F_CPU 16000000
#include <avr/io.h>
#include <ub_mk3_2560/MK3_2560_LCD.h>
#include <UB_EXT_MODULE/EXT_MOD_BMA180.h>


//-----------------------------------------------------------------------------
// Hinweis : Quick-Jumper Port-C+A muss gesetzt sein
//           Externes-Modul (mit BMA180) muss angeschlossen sein
//           (siehe H-File vom BMA180)
//           Nach der init des BMA180 werden die X,y,Z-Rohdaten
//           und die Temperatur-Rohdaten auf dem Display angezeigt
//  
//           Vorsicht : es sind keine G-Werte oder Grad-Celsius-Werte !!
//-----------------------------------------------------------------------------
int main (void) {
    char wert;
    unsigned int uint;
    unsigned int pause=0;

	MK3_INIT_LCD();					// init des LCD
	
	EXT_INIT_BMA180();              // BMA180 initialisieren

	MK3_LCD_CLEAR();				// LCD loeschen
	MK3_LCD_LIGHT(true);				// beleuchtung einschalten

	MK3_LCD_STRING_AT(0,0,"BMA180-Projekt [V1.2]");
	
	if(EXT_BMA180_OK==true) {
	  MK3_LCD_STRING_AT(0,16,"BMA180 an SPI OK");
	  
	  // Filter einstellen
	  MK3_BMA180_setFilter(BMA_FILTER_10Hz);
	  // Interrupt-Mode aktivieren
	  MK3_BMA180_enableINT(true);
	  
	  while (true) {
        if(EXT_BMA180.raw.new_data==true) {
          // neue Daten sind vorhanden
          EXT_BMA180.raw.new_data=false;
          // X-Daten anzeigen
          MK3_LCD_STRING_AT(0,32,"X=       ");
          if(EXT_BMA180.raw.x_negativ==true) MK3_LCD_STRING_AT(12,32,"-");
          uint=EXT_BMA180.raw.x_achse; 
          MK3_LCD_UINT_AT(18,32,uint);
          // Y-Daten anzeigen
          MK3_LCD_STRING_AT(0,40,"Y=       ");
          if(EXT_BMA180.raw.y_negativ==true) MK3_LCD_STRING_AT(12,40,"-");
          uint=EXT_BMA180.raw.y_achse; 
          MK3_LCD_UINT_AT(18,40,uint);
          // Z-Daten anzeigen
          MK3_LCD_STRING_AT(0,48,"Z=       ");
          if(EXT_BMA180.raw.z_negativ==true) MK3_LCD_STRING_AT(12,48,"-");
          uint=EXT_BMA180.raw.z_achse; 
          MK3_LCD_UINT_AT(18,48,uint);
          // Temperatur anzeigen
          MK3_LCD_STRING_AT(0,56,"T=       ");
          if(EXT_BMA180.raw.t_negativ==true) MK3_LCD_STRING_AT(12,56,"-");
          uint=EXT_BMA180.raw.temperatur; 
          MK3_LCD_UINT_AT(18,56,uint);          
        }
      }
	}
	else {
	  MK3_LCD_STRING_AT(0,16,"BMA180 nicht gefunden");
	  
	  while(true) {
	  
	  }
	}
	return 0;
}

