//-----------------------------------------------------------------------------
// Title      : prj_ub003_mk3_bma180
//-----------------------------------------------------------------------------
// Funktion   : Beschleunigungs-Sensor-Modul (BMA180)
// Schaltung  : myAVR MK3 + BMA180-Modul
//-----------------------------------------------------------------------------
// Prozessor  : ATMega2560
// Takt       : 16 MHz
// Sprache    : C
// Date       : 18.12.2010
// Version    : 1.3
// Autor      : UB
//-----------------------------------------------------------------------------
#define F_CPU 16000000
#include <avr/io.h>
#include <ub_mk3_2560/MK3_2560_LCD.h>
#include <ub_mk3_2560/MK3_2560_KEY.h>
#include <UB_EXT_MODULE/EXT_MOD_BMA180.h>


#define ball_r 2   // radius vom ball

void drawBall(char x,char y);
void deleteBall(char x,char y);

//-----------------------------------------------------------------------------
// Hinweis : Quick-Jumper Port-C+A und Port-K muss gesetzt sein
//           Externes-Modul (mit BMA180) muss angeschlossen sein
//           (siehe H-File vom BMA180)
//           Nach dem druecken von Button-1 wird das Spiel gestartet
//           ein Ball kann per Kippen (X,Y) gesteuert werden
//-----------------------------------------------------------------------------
int main (void) {
    int xpos=64,ypos=32;;
    int xold=64,yold=32;
    unsigned int uint;
    bool start=false;

	MK3_INIT_LCD();					// init des LCD
	MK3_INIT_KEY();                 // init der Tasten
	
	EXT_INIT_BMA180();              // BMA180 initialisieren

	MK3_LCD_CLEAR();				// LCD loeschen
	MK3_LCD_LIGHT(true);				// beleuchtung einschalten

	MK3_LCD_STRING_AT(0,0,"BMA180-Projekt [V1.3]");
	
	if(EXT_BMA180_OK==true) {
	  MK3_LCD_STRING_AT(0,16,"BMA180 an SPI OK");
	  
	  // Filter einstellen
	  MK3_BMA180_setFilter(BMA_FILTER_10Hz);
	  // Interrupt-Mode aktivieren
	  MK3_BMA180_enableINT(true);
	  
	  MK3_LCD_STRING_AT(0,32,"Button-1 = START");
	  
	  while (start==false) {
	    start=MK3_KEY_SET(BUTTON1);
	  }
	  
	  MK3_LCD_CLEAR();
	  
	  // ball zeichnen
	  drawBall(xpos,ypos);
	  
	  while (true) {
        if(EXT_BMA180.raw.new_data==true) {
          // neue Daten sind vorhanden
          EXT_BMA180.raw.new_data=false;

          // Y-Auswerten (als X-Richtung)
          uint=EXT_BMA180.raw.y_achse/250;
          if(EXT_BMA180.raw.y_negativ==true)
            xpos=xpos-uint;
          else
            xpos=xpos+uint;
          if(xpos<ball_r) xpos=ball_r;
          if(xpos>=LCD_MAXX-ball_r-1) xpos=LCD_MAXX-ball_r-1;
          
          // X-Auswerten (als Y-Richtung)
          uint=EXT_BMA180.raw.x_achse/250;
          if(EXT_BMA180.raw.x_negativ==true)
            ypos=ypos-uint;
          else
            ypos=ypos+uint;
          if(ypos<ball_r) ypos=ball_r;
          if(ypos>=LCD_MAXY-ball_r-1) ypos=LCD_MAXY-ball_r-1;          
          
          // ball zeichnen
          if((xpos!=xold) || (ypos!=yold)) {
            deleteBall(xold,yold);
            drawBall(xpos,ypos);
            xold=xpos;
            yold=ypos;
          }
        }
      }
	}
	else {
	  MK3_LCD_STRING_AT(0,16,"BMA180 nicht gefunden");
	  
	  while(true) {
	  
	  }
	}
	return 0;
}

void drawBall(char x,char y) {
  int n,m;
  
  for(n=-1*ball_r;n<=ball_r;n++) {
    for(m=-1*ball_r;m<=ball_r;m++) {
      MK3_LCD_PIXEL_AT(x+n,y+m,MODE_SET);
    }
  }
}

void deleteBall(char x,char y) {
  int n,m;
  
  for(n=-1*ball_r;n<=ball_r;n++) {
    for(m=-1*ball_r;m<=ball_r;m++) {
      MK3_LCD_PIXEL_AT(x+n,y+m,MODE_RESET);
    }
  }  
}
