//-----------------------------------------------------------------------------
// Title      : prj_ub003_mk3_bma180
//-----------------------------------------------------------------------------
// Funktion   : Beschleunigungs-Sensor-Modul (BMA180)
// Schaltung  : myAVR MK3 + BMA180-Modul
//-----------------------------------------------------------------------------
// Prozessor  : ATMega2560
// Takt       : 16 MHz
// Sprache    : C
// Date       : 19.12.2010
// Version    : 1.4
// Autor      : UB
// CompilerOption:  -O0 
// LinkerOption:    -Wl,-u,vfprintf -lprintf_flt -lm 
//-----------------------------------------------------------------------------
#define F_CPU 16000000
#include <avr/io.h>
#include <ub_mk3_2560/MK3_2560_LCD.h>
#include <UB_EXT_MODULE/EXT_MOD_BMA180.h>


//-----------------------------------------------------------------------------
// Hinweis : Quick-Jumper Port-C+A muss gesetzt sein
//           Externes-Modul (mit BMA180) muss angeschlossen sein
//           (siehe H-File vom BMA180)
//           Nach der init des BMA180 werden die X,y,Z-Daten
//           und die Temperatur-Daten auf dem Display angezeigt
//
//           Hinweis : 1000 mg = 1g
//
//-----------------------------------------------------------------------------
int main (void) {
    unsigned int uint;
    float f=0;

	MK3_INIT_LCD();					// init des LCD
	
	EXT_INIT_BMA180();              // BMA180 initialisieren

	MK3_LCD_CLEAR();				// LCD loeschen
	MK3_LCD_LIGHT(true);				// beleuchtung einschalten

	MK3_LCD_STRING_AT(0,0,"BMA180-Projekt [V1.4]");
	
	if(EXT_BMA180_OK==true) {
	  MK3_LCD_STRING_AT(0,16,"BMA180 an SPI OK");
	  
	  // Filter einstellen
	  MK3_BMA180_setFilter(BMA_FILTER_10Hz);
	  // Range einstellen
	  MK3_BMA180_setRange(BMA_RANGE_2G); // +/- 2g
	  // Interrupt-Mode aktivieren
	  MK3_BMA180_enableINT(true);
	  
	  while (true) {
        if(EXT_BMA180.raw.new_data==true) {
          // neue Daten sind vorhanden
          EXT_BMA180.raw.new_data=false;
          // X-Daten anzeigen
          MK3_LCD_STRING_AT(0,32,"X=");
          f=EXT_BMA180.data.x_achse;
          MK3_LCD_PRINT_FLOAT(f);
          MK3_LCD_PRINT_STRING(" mg  ");
          // Y-Daten anzeigen
          MK3_LCD_STRING_AT(0,40,"Y=");
          f=EXT_BMA180.data.y_achse;
          MK3_LCD_PRINT_FLOAT(f);
          MK3_LCD_PRINT_STRING(" mg  ");
          // Z-Daten anzeigen
          MK3_LCD_STRING_AT(0,48,"Z=");
          f=EXT_BMA180.data.z_achse;
          MK3_LCD_PRINT_FLOAT(f);
          MK3_LCD_PRINT_STRING(" mg  ");
          // Temperatur anzeigen
          MK3_LCD_STRING_AT(0,56,"T=");
          f=EXT_BMA180.data.temperatur;
          MK3_LCD_PRINT_FLOAT(f);
          MK3_LCD_PRINT_STRING(" C  ");      
        }
      }
	}
	else {
	  MK3_LCD_STRING_AT(0,16,"BMA180 nicht gefunden");
	  
	  while(true) {
	  
	  }
	}
	return 0;
}

