//-----------------------------------------------------------------------------
// MK3_2560_SPI
// Version 1.4
// 02.11.2011 / UB
// "www.Mikrocontroller-4U.de"
// mc-4u(@)t-online.de 
//-----------------------------------------------------------------------------
// Fuer das myAVR MK3 Board
// mit ATMega-2560 @ 16MHz
// SPI-Funktionen
//-----------------------------------------------------------------------------
// das File muss im Ordner
// "myAVR/WinAVR/AVR/Include/UB_MK3_2560/"
// liegen und mit #include <UB_MK3_2560/MK3_2560_SPI.h>
// eingebunden werden
//-----------------------------------------------------------------------------
// Belegt : Port-B (Bit1 bis Bit3)
//-----------------------------------------------------------------------------

#ifndef MK3_2560_SPI    // Wichtig !!
#define MK3_2560_SPI 1  // damit wird das File nur einmal eingebunden


//-----------------------------------------------------------------------------
// Hier koennen Funktionen die nicht benutzt werden
// abgeschaltet werden...einfach den DEFINE von "1" auf "0" aendern
//-----------------------------------------------------------------------------
// keine

//-----------------------------------------------------------------------------
// INFOS zur Benutzung :
// 01. Funktion "MK3_INIT_SPI" starten
// 02. Funktion "MK3_SPI_SEND" sendet und empfaengt ein Byte per SPI
//     >> das ChipSelect-Signal wird hier NICHT bearbeitet...
//     ...das muss in einer uebergeordneten Funktion gesetzt werden
// 03. Funtkion "MK3_SPI_SET_MODE" falls der Default Clock-Mode nicht passt
// 04. Funktion "MK3_SPI_SET_FRQ" falls die Default Frq nicht passt
//-----------------------------------------------------------------------------

//-----------------------------------------------------------------------------
// Enumerationen fuer die Funktioen
//-----------------------------------------------------------------------------

typedef enum {
  SPI_MODE_0 = 0,  // CPOL=0  CPHA=0  (default)
  SPI_MODE_1,      // CPOL=0  CPHA=1
  SPI_MODE_2,      // CPOL=1  CPHA=0
  SPI_MODE_3       // CPOL=1  CPHA=1
}SPI_CLKMODE; 

typedef enum {
  SPI_CLK_DIV_2 = 0,  // Clk-Teiler = 2   (@16MHz = 8MHz)
  SPI_CLK_DIV_4,      // Clk-Teiler = 4   (@16MHz = 4MHz)
  SPI_CLK_DIV_8,      // Clk-Teiler = 8   (@16MHz = 2MHz)
  SPI_CLK_DIV_16,     // Clk-Teiler = 16  (@16MHz = 1MHz)    (default)
  SPI_CLK_DIV_32,     // Clk-Teiler = 32  (@16MHz = 500kHz)
  SPI_CLK_DIV_64,     // Clk-Teiler = 64  (@16MHz = 250kHz)
  SPI_CLK_DIV_128     // Clk-Teiler = 128 (@16MHz = 125kHz)
}SPI_CLKFRQ;


//-----------------------------------------------------------------------------
// Funktionen die vom MAIN benutzt werden koennen
//-----------------------------------------------------------------------------
void MK3_INIT_SPI(void);	          // zum initialis. der SPI-Schnittstelle
unsigned char MK3_SPI_SEND(unsigned char wert);
void MK3_SPI_SET_MODE(SPI_CLKMODE mode);  // zum aendern des Clock-Mode
void MK3_SPI_SET_FRQ(SPI_CLKFRQ frq);     // zum aendern der Clock-Frq
//-----------------------------------------------------------------------------



//-----------------------------------------------------------------------------
// Port-Pin definition
//-----------------------------------------------------------------------------
#define MK3_DDR_SPI DDRB	// DDR-Register des SPI

#define MK3_SPI_SCK 0x02    	// SCK von SPI
#define MK3_SPI_MOSI 0x04       // MOSI von SPI
#define MK3_SPI_MISO 0x08       // MISO von SPI




//-----------------------------------------------------------------------------
void MK3_INIT_SPI(void) {	// zum initialisieren der SPI-Schnittstelle
  MK3_DDR_SPI|=0x01;
  PORTB|=0x01;

  MK3_DDR_SPI|=MK3_SPI_SCK;    // SCK als Ausgang
  MK3_DDR_SPI|=MK3_SPI_MOSI;   // MOSI als Ausgang
  MK3_DDR_SPI&=~MK3_SPI_MISO;  // MISO als Eingang

  // default Einstellung :
  // Clock-Polarity = Lo
  // Clock-Phase    = Lo
  // Frq-Teiler = 16 -> 1MHz

  SPCR=0x00;
  SPCR|=0x01; // CLK = 1MHz (@16MHz)
  SPCR|=0x10; // Master Mode
  SPCR|=0x40; // SPI aktivieren
}




//-----------------------------------------------------------------------------
unsigned char MK3_SPI_SEND(unsigned char wert) {
  // sendet und empfaengt ein byte per SPI
  unsigned char ret_wert;
  unsigned int n=0;
	
  SPDR = wert;           // sendet ein Byte

  for(n=0;n<50000;n++) {
    if((SPSR & 0x80)!=0) break;  // warte bis gesendet wurde
  }

  ret_wert=SPDR;         // empfaengt ein byte

  return(ret_wert);
}

//-----------------------------------------------------------------------------
void MK3_SPI_SET_MODE(SPI_CLKMODE mode) { // zum aendern des Clock-Mode
  if(mode==SPI_MODE_0) {
    SPCR&=~0x08; // CPOL=0
    SPCR&=~0x04; // CPHA=0
  }
  if(mode==SPI_MODE_1) {
    SPCR&=~0x08; // CPOL=0
    SPCR|=0x04;  // CPHA=1
  }
  if(mode==SPI_MODE_2) {
    SPCR|=0x08;  // CPOL=1
    SPCR&=~0x04; // CPHA=0
  }
  if(mode==SPI_MODE_3) {
    SPCR|=0x08;  // CPOL=1
    SPCR|=0x04;  // CPHA=1
  }
}

//-----------------------------------------------------------------------------
void MK3_SPI_SET_FRQ(SPI_CLKFRQ frq) {     // zum aendern der Clock-Frq
  if(frq==SPI_CLK_DIV_2) {
    SPSR|=0x01;
    SPCR&=~0x01;
    SPCR&=~0x02;
  }
  if(frq==SPI_CLK_DIV_4) {
    SPSR&=~0x01;
    SPCR&=~0x01;
    SPCR&=~0x02;
  }
  if(frq==SPI_CLK_DIV_8) {
    SPSR|=0x01;
    SPCR|=0x01;
    SPCR&=~0x02;
  }
  if(frq==SPI_CLK_DIV_16) {
    SPSR&=~0x01;
    SPCR|=0x01;
    SPCR&=~0x02;
  }
  if(frq==SPI_CLK_DIV_32) {
    SPSR|=0x01;
    SPCR&=~0x01;
    SPCR|=0x02;
  }
  if(frq==SPI_CLK_DIV_64) {
    SPSR&=~0x01;
    SPCR&=~0x01;
    SPCR|=0x02;
  }
  if(frq==SPI_CLK_DIV_128) {
    SPSR&=~0x01;
    SPCR|=0x01;
    SPCR|=0x02;
  }
}

#endif  // Ende von #define MK3_2560_SPI


